-- Pulisco se esiste il DB del progetto
DROP DATABASE bdsi_ex01  \p;

-- Crea il nuovo database per le prove
CREATE DATABASE bdsi_ex01  \p;

-- Passa al database di prova
USE bdsi_ex01  \p;

-- Mostra che non ci sono tabelle nel database
SHOW TABLES  \p;

-- Crea le tabelle
-- Tabella Studenti
CREATE TABLE STUDENTI (
	ID int, 
	NOME varchar(40), 
	MATRICOLA char(10), 
	DATA_NASCITA date, 
	SESSO char(1) NULL, 
	IN_CORSO char(1) DEFAULT 'S',  
	PRIMARY KEY (ID) )  \p;


-- CREATE TABLE STUDENTI (ID int, NOME varchar(40), MATRICOLA char(10), DATA_NASCITA date, SESSO char(1), IN_CORSO char(1)  )  \p;
-- ALTER TABLE STUDENTI ADD PRIMARY KEY PK_STUDENTI (ID)  \p;


-- inserimento singolo
INSERT INTO STUDENTI VALUES
(1, 'PAOLO BRNST', '753002312A', '1965/10/03', 'M', 'N' );

-- serie di inserimenti
INSERT INTO STUDENTI VALUES
(2, 'MARIO ROSSI',    '8990392323', '1980/05/24', 'M', 'N' ),
(3, 'MONICA TOGNI',   'A434873739', '1990-01-06', 'F', 'S' )  \p;

-- inserimento non a buon fino : chiave duplicata
INSERT INTO STUDENTI VALUES
(1, 'PINCO PALINO', '1234567890', '1925/12/31', 'M', 'N' )  \p;


-- serie di inserimenti con specificati solo alcuni campi
INSERT INTO STUDENTI (ID, NOME, MATRICOLA, DATA_NASCITA)
VALUES
(5, 'ANNA LUDOVI',  '8434843424', '1970-02-12' ),
(6, 'JOHN WALKER',    'NJ8434-23', '1972-3-2' ),
(18, 'MARIANNA SILA','A373913001', '86-4-1' )  \p;


-- altra serie di inserimenti con specificati solo alcuni campi
INSERT INTO STUDENTI (ID, NOME, MATRICOLA, DATA_NASCITA, SESSO)
VALUES
(9, 'FRANCESCA MONTI',  '9434299', '1975-05-12', 'F' )  \p;


-- creazione di indice univoco su campo senza valori duplicati
ALTER TABLE STUDENTI ADD UNIQUE IDX_STUDENTI (MATRICOLA)  \p;


-- inserimento non a buon fine perche' in campo univoco (matricola) valore gia' presente
INSERT INTO STUDENTI (ID, NOME, MATRICOLA, DATA_NASCITA, SESSO)
VALUES
(11, 'ENRICO MONTI',  '9434299', '1975-07-21', 'M' )  \p;







-- Tabella PROFESSORI
CREATE TABLE PROFESSORI (
	ID_PROF int, 
	NOME varchar(40), 
	TITOLO varchar(40), 
	C_FISC char(16), 
	DATA_NASCITA date, 
	SESSO char(1) NULL, 
	PRIMARY KEY (ID_PROF) )  \p;



-- Mostra le tabelle nel database
SHOW TABLES  \p;


-- inserimento dei record della tabella PROFESSORI
INSERT INTO PROFESSORI VALUES
(1, 'MOSCATO UGO', 'PROF.', 'MSCUGO01A23B456C', '1955/12/25', 'M' ),
(2, 'GHEZZI CARLO', 'PROF.', 'GHZCRL12B34C567D', '1948/10/5', 'M' ),
(3, 'BRUNASTI PAOLO', 'ING.', 'BRNPLO65R03F205M', '1965/10/3', 'M' ),
(4, 'RUBBIA CARLO', 'MAGNIF.', 'RBBCRL01C02F232H', '1934/5/23', 'M' ),
(5, 'LEVI RITA', 'NOBEL', 'LVMRTA03F32R231X', '1925/8/2', 'F' ),
(8, 'MONTESSORI MARIA', 'MAESTRA', 'MNTMRI78D23M421L', '1902/5/21', 'F' ),
(10, 'NATTA CARLO', 'PROF.', 'NTTCRL23A43S432A', '1908/3/4', 'M' ),
(6, 'VAGHI LAURA', 'PROF.SA', 'VGHLRA67G89H123H', '1943/2/2', 'F' );







-- Tabella Corsi
CREATE TABLE CORSI (
	ID_CORSO int, 
	CODICE char(5), 
	TITOLO varchar(40), 
	DESCRIZIONE text, 
	DATA_INIZIO date, 
	CREDITI int DEFAULT 2, 
	ANNO int ,  
	REF_PROF int,
	PRIMARY KEY (ID_CORSO),
	UNIQUE INDEX IDX_CORSI_CODICE (CODICE) )
	  \p;


-- Mostra le tabelle nel database
SHOW TABLES  \p;


-- inserimento dei record della tabella CORSI
INSERT INTO CORSI VALUES
(1, 'IGEBN', 'INF. ECON. BANC.', 'Corso molto difficile di informatica per gli studenti di economia ad indirizzo bancario', '2007/01/03', 6, 2, 1 ),
(2, 'IGETU', 'INF. ECON. TUR.', 'Corso molto difficile di informatica per gli studenti di economia ad indirizzo turistico', '2007/01/03', 6, 2, 10 ),
(3, 'DRPR1', 'DIR. PRIVATO I', 'Prima parte di Diritto privato (un mattone di 1200 pagine.....', '2006/10/05', 3, 1, 6 ),
(5, 'DISIN', 'DISEGNO IND.', 'Disegno Industriale a mano libera', '2007/1/12', 4, 3, 3 ),
(6, 'GIMN2', 'GINNASTICA ART. 2', 'Ginnastica Artistica Avanzata', '2007/6/11', 2, 2, 0 ),
(4, 'DRPR2', 'DIR. PRIVATO II', 'Seconda parte di Diritto privato (un mattone di altre 1500 pagine.....', '2007/01/15', 4, 1, 2 )  \p;







-- Tabella di relazione tra studenti e corsi
CREATE TABLE ESAMI_STUDENTE (
	ID_ESAME_STUDENTE SERIAL,
	RIF_STUDENTE int,
	ID_CORSO int,
	DATA_ESAME date,
	VOTO int,
	PRIMARY KEY (ID_ESAME_STUDENTE),
	UNIQUE INDEX IDX_ESAMI_STUDENTE (RIF_STUDENTE, ID_CORSO, DATA_ESAME),
	CONSTRAINT FOREIGN KEY FK_CORSI (ID_CORSO) REFERENCES CORSI(ID_CORSO)
	)  \p;
	
ALTER TABLE ESAMI_STUDENTE ADD CONSTRAINT FOREIGN KEY FK_STUDENTI (RIF_STUDENTE) REFERENCES STUDENTI(ID)  \p;


-- inserimento dei record della tabella ESAMI_STUDENTE
INSERT INTO ESAMI_STUDENTE 
	(RIF_STUDENTE, ID_CORSO, DATA_ESAME, VOTO )
VALUES
	(1, 1, '2000-12-4', 13),
	(1, 1, '2001-01-24', 16),
	(1, 1, '2001-04-22', 30),
	(1, 3, '1998-11-4', 18),
	(1, 4, '1999-3-15', 23),
	(2, 3, '1999-3-15', 0),
	(2, 3, '2000-1-5', 25),
	(2, 4, '2003-3-18', 23),
	(2, 1, '2001-01-24', 30),
	(5, 2, '2003-01-24', 24),
	(5, 3, '2004-03-29', 26),
	(18, 1, '2001-01-24', 28),
	(18, 4, '2006-12-4', 30)  \p;



SHOW TABLES \p;
